@@ -2,7 +2,7 @@ package Net::GitHub;
 
 use Net::GitHub::V3;
 
-our $VERSION = '0.85';
+our $VERSION = '0.86';
 our $AUTHORITY = 'cpan:FAYLAND';
 
 sub new {
@@ -26,9 +26,12 @@ Net::GitHub - Perl Interface for github.com
         login => 'fayland', pass => 'secret'
     );
 
-    # Pass api_url for GitHub Enterprise installations
+    # Pass api_url for GitHub Enterprise installations. Do not include a
+    # trailing slash
     my $github = Net::GitHub->new(  # Net::GitHub::V3
-        login => 'fayland', pass => 'secret',  api_url => 'https://gits.aresweet.com/api/v3'
+        login =>   'fayland',
+        pass =>    'secret',
+        api_url => 'https://gits.aresweet.com/api/v3'
     );
 
     # suggested
